@@ -123,6 +123,36 @@ sub new {
 		Wx::wxDefaultSize,
 	);
 
+	$self->{m_checkBox2} = Wx::CheckBox->new(
+		$self,
+		-1,
+		Wx::gettext('Check Me!'),
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+	);
+
+	$self->{m_checkBox3} = Wx::CheckBox->new(
+		$self,
+		-1,
+		Wx::gettext('Check Me!'),
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+	);
+
+	$self->{m_checkBox4} = Wx::CheckBox->new(
+		$self,
+		-1,
+		Wx::gettext('Check Me!'),
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+	);
+
+	my $gSizer1 = Wx::GridSizer->new( 1, 2, 3, 4 );
+	$gSizer1->Add( $self->{m_checkBox1}, 0, Wx::wxALL, 5 );
+	$gSizer1->Add( $self->{m_checkBox2}, 0, Wx::wxALL, 5 );
+	$gSizer1->Add( $self->{m_checkBox3}, 0, Wx::wxALL, 5 );
+	$gSizer1->Add( $self->{m_checkBox4}, 0, Wx::wxALL, 5 );
+
 	my $bSizer2 = Wx::BoxSizer->new( Wx::wxVERTICAL );
 	$bSizer2->Add( $self->{m_staticText1}, 0, Wx::wxALL, 5 );
 	$bSizer2->Add( 10, 5, 1, Wx::wxEXPAND, 5 );
@@ -133,7 +163,7 @@ sub new {
 	$bSizer2->Add( $self->{m_listBox1}, 0, Wx::wxALL, 5 );
 	$bSizer2->Add( $self->{m_listCtrl1}, 0, Wx::wxALL | Wx::wxEXPAND, 5 );
 	$bSizer2->Add( $self->{m_htmlWin1}, 0, Wx::wxALL | Wx::wxEXPAND, 5 );
-	$bSizer2->Add( $self->{m_checkBox1}, 0, Wx::wxALL, 5 );
+	$bSizer2->Add( $gSizer1, 1, Wx::wxEXPAND, 5 );
 
 	my $bSizer1 = Wx::BoxSizer->new( Wx::wxHORIZONTAL );
 	$bSizer1->Add( $bSizer2, 1, Wx::wxEXPAND, 5 );
